from setuptools import setup
setup(name='pydatamake',
      version='0.1',
      description='pydatamake',
      author='lijun',
      license='MIT',
      author_email='asdfzxcvqwer123a@126.com',
      packages=['pydatamake'],
      zip_safe=False)